@@ -40,14 +40,6 @@ function _aws_cdk_aws_certificatemanager_CertificateProps(p) {
         _aws_cdk_aws_certificatemanager_ValidationMethod(p.validationMethod);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_certificatemanager_CfnCertificateProps(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.tags))
-        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
-    visitedObjects.delete(p);
-}
 function _aws_cdk_aws_certificatemanager_CertificationValidationProps(p) {
     if (p == null)
         return;
@@ -58,6 +50,14 @@ function _aws_cdk_aws_certificatemanager_CertificationValidationProps(p) {
         _aws_cdk_aws_certificatemanager_ValidationMethod(p.method);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_certificatemanager_CfnCertificateProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.tags))
+        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_aws_certificatemanager_DnsValidatedCertificate(p) {
 }
 function _aws_cdk_aws_certificatemanager_CfnAccount(p) {
@@ -89,5 +89,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_certificatemanager_ValidationMethod, _aws_cdk_aws_certificatemanager_PrivateCertificateProps, _aws_cdk_aws_certificatemanager_CfnAccountProps, _aws_cdk_aws_certificatemanager_ICertificate, _aws_cdk_aws_certificatemanager_DnsValidatedCertificateProps, _aws_cdk_aws_certificatemanager_CertificateProps, _aws_cdk_aws_certificatemanager_CfnCertificateProps, _aws_cdk_aws_certificatemanager_CertificationValidationProps, _aws_cdk_aws_certificatemanager_DnsValidatedCertificate, _aws_cdk_aws_certificatemanager_CfnAccount, _aws_cdk_aws_certificatemanager_CfnAccount_ExpiryEventsConfigurationProperty, _aws_cdk_aws_certificatemanager_CertificateValidation, _aws_cdk_aws_certificatemanager_PrivateCertificate, _aws_cdk_aws_certificatemanager_Certificate, _aws_cdk_aws_certificatemanager_CfnCertificate, _aws_cdk_aws_certificatemanager_CfnCertificate_DomainValidationOptionProperty };
+module.exports = { print, _aws_cdk_aws_certificatemanager_ValidationMethod, _aws_cdk_aws_certificatemanager_PrivateCertificateProps, _aws_cdk_aws_certificatemanager_CfnAccountProps, _aws_cdk_aws_certificatemanager_ICertificate, _aws_cdk_aws_certificatemanager_DnsValidatedCertificateProps, _aws_cdk_aws_certificatemanager_CertificateProps, _aws_cdk_aws_certificatemanager_CertificationValidationProps, _aws_cdk_aws_certificatemanager_CfnCertificateProps, _aws_cdk_aws_certificatemanager_DnsValidatedCertificate, _aws_cdk_aws_certificatemanager_CfnAccount, _aws_cdk_aws_certificatemanager_CfnAccount_ExpiryEventsConfigurationProperty, _aws_cdk_aws_certificatemanager_CertificateValidation, _aws_cdk_aws_certificatemanager_PrivateCertificate, _aws_cdk_aws_certificatemanager_Certificate, _aws_cdk_aws_certificatemanager_CfnCertificate, _aws_cdk_aws_certificatemanager_CfnCertificate_DomainValidationOptionProperty };
 module.exports.DeprecationError = DeprecationError;
